@@ -892,8 +892,6 @@ main(int argc, char **argv)
 	/* Create a window to hold the scrolling shell, and hook its
 	 * delete event to the quit function.. */
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_container_set_resize_mode(GTK_CONTAINER(window),
-				      GTK_RESIZE_IMMEDIATE);
         if (border_width_string) {
                 guint w;
 
